@@ -1,6 +1,7 @@
 import logging
 import threading
 from urlparse import parse_qs
+from urllib import urlencode
 
 from sqlalchemy import create_engine
 from migrate.versioning.util import construct_engine
@@ -32,6 +33,8 @@ class Database(object):
                 schema_qs = query.pop('schema', query.pop('searchpath', []))
                 if len(schema_qs):
                     schema = schema_qs.pop()
+            if len(query):
+                url = url + '?' + urlencode(query, doseq=True)
         self.schema = schema
         engine = create_engine(url, **kw)
         self.url = url
@@ -121,12 +124,12 @@ class Database(object):
         try:
             log.debug("Creating table: %s on %r" % (table_name, self.engine))
             table = SQLATable(table_name, self.metadata)
-            if primary_type is 'Integer':
+            if primary_type == 'Integer':
                 auto_flag = False
-                if primary_id is 'id':
+                if primary_id == 'id':
                     auto_flag = True
                 col = Column(primary_id, Integer, primary_key=True, autoincrement=auto_flag)
-            elif primary_type is 'Text':
+            elif primary_type == 'Text':
                 col = Column(primary_id, Text, primary_key=True)
             else:
                 raise DatasetException(
